==> huaweicloudsdkgaussdb-3.1.88-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/update_new_node_auto_add_switch_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateNewNodeAutoAddSwitchRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'switch_status': 'str',
        'weight': 'int'
    }

    attribute_map = {
        'switch_status': 'switch_status',
        'weight': 'weight'
    }

    def __init__(self, switch_status=None, weight=None):
        """UpdateNewNodeAutoAddSwitchRequestBody

        The model defined in huaweicloud sdk

        :param switch_status: 是否开启新增节点自动加入该Proxy。  取值范围： - ON：开启。 - OFF：关闭。
        :type switch_status: str
        :param weight: 新增节点的读权重：  - 新增节点自动加入为ON，取值为0~1000。 - 新增节点自动加入为OFF，则可不输入读权重。
        :type weight: int
        """
        
        

        self._switch_status = None
        self._weight = None
        self.discriminator = None

        self.switch_status = switch_status
        if weight is not None:
            self.weight = weight

    @property
    def switch_status(self):
        """Gets the switch_status of this UpdateNewNodeAutoAddSwitchRequestBody.

        是否开启新增节点自动加入该Proxy。  取值范围： - ON：开启。 - OFF：关闭。

        :return: The switch_status of this UpdateNewNodeAutoAddSwitchRequestBody.
        :rtype: str
        """
        return self._switch_status

    @switch_status.setter
    def switch_status(self, switch_status):
        """Sets the switch_status of this UpdateNewNodeAutoAddSwitchRequestBody.

        是否开启新增节点自动加入该Proxy。  取值范围： - ON：开启。 - OFF：关闭。

        :param switch_status: The switch_status of this UpdateNewNodeAutoAddSwitchRequestBody.
        :type switch_status: str
        """
        self._switch_status = switch_status

    @property
    def weight(self):
        """Gets the weight of this UpdateNewNodeAutoAddSwitchRequestBody.

        新增节点的读权重：  - 新增节点自动加入为ON，取值为0~1000。 - 新增节点自动加入为OFF，则可不输入读权重。

        :return: The weight of this UpdateNewNodeAutoAddSwitchRequestBody.
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this UpdateNewNodeAutoAddSwitchRequestBody.

        新增节点的读权重：  - 新增节点自动加入为ON，取值为0~1000。 - 新增节点自动加入为OFF，则可不输入读权重。

        :param weight: The weight of this UpdateNewNodeAutoAddSwitchRequestBody.
        :type weight: int
        """
        self._weight = weight

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateNewNodeAutoAddSwitchRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/update_new_node_auto_add_switch_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateNewNodeAutoAddSwitchRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'switch_status': 'str',
        'weight': 'int'
    }

    attribute_map = {
        'switch_status': 'switch_status',
        'weight': 'weight'
    }

    def __init__(self, switch_status=None, weight=None):
        r"""UpdateNewNodeAutoAddSwitchRequestBody

        The model defined in huaweicloud sdk

        :param switch_status: 是否开启新增节点自动加入该Proxy。  取值范围： - ON：开启。 - OFF：关闭。
        :type switch_status: str
        :param weight: 新增节点的读权重：  - 新增节点自动加入为ON，取值为0~1000。 - 新增节点自动加入为OFF，则可不输入读权重。
        :type weight: int
        """
        
        

        self._switch_status = None
        self._weight = None
        self.discriminator = None

        self.switch_status = switch_status
        if weight is not None:
            self.weight = weight

    @property
    def switch_status(self):
        r"""Gets the switch_status of this UpdateNewNodeAutoAddSwitchRequestBody.

        是否开启新增节点自动加入该Proxy。  取值范围： - ON：开启。 - OFF：关闭。

        :return: The switch_status of this UpdateNewNodeAutoAddSwitchRequestBody.
        :rtype: str
        """
        return self._switch_status

    @switch_status.setter
    def switch_status(self, switch_status):
        r"""Sets the switch_status of this UpdateNewNodeAutoAddSwitchRequestBody.

        是否开启新增节点自动加入该Proxy。  取值范围： - ON：开启。 - OFF：关闭。

        :param switch_status: The switch_status of this UpdateNewNodeAutoAddSwitchRequestBody.
        :type switch_status: str
        """
        self._switch_status = switch_status

    @property
    def weight(self):
        r"""Gets the weight of this UpdateNewNodeAutoAddSwitchRequestBody.

        新增节点的读权重：  - 新增节点自动加入为ON，取值为0~1000。 - 新增节点自动加入为OFF，则可不输入读权重。

        :return: The weight of this UpdateNewNodeAutoAddSwitchRequestBody.
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        r"""Sets the weight of this UpdateNewNodeAutoAddSwitchRequestBody.

        新增节点的读权重：  - 新增节点自动加入为ON，取值为0~1000。 - 新增节点自动加入为OFF，则可不输入读权重。

        :param weight: The weight of this UpdateNewNodeAutoAddSwitchRequestBody.
        :type weight: int
        """
        self._weight = weight

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateNewNodeAutoAddSwitchRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
